# MPENN - Massive Picture Editing for Neural Networks

MPENN is a cutting-edge software solution designed to revolutionize the way we handle image processing and editing, particularly for applications involving neural networks. This versatile tool combines the functionality of a video-to-picture converter with a powerful editor, allowing for the quick and efficient manipulation and scaling of images in large volumes. Whether you're working on machine learning datasets, enhancing digital media assets, or simply need a robust tool for bulk image editing, MPENN is your go-to solution.

## Features

MPENN provides a suite of powerful features designed to streamline the process of converting, editing, and managing large sets of images. Here's what you can expect:

- **Video to Picture Sequence Conversion**: Effortlessly convert videos into sequences of high-quality images, ready for editing or analysis.

- **Fast Resize Capabilities**: Quickly adjust the sizes of your images to meet specific requirements without compromising on quality.

- **Bounding Boxes with Customization**: Annotate your images with bounding boxes. MPENN allows you to customize these boxes with a variety of colors and thicknesses to suit your needs.

- **Data Tracking and Management**: For each output folder, MPENN generates a detailed `.json` file. This file contains important information about each image, including bounding box details, making it easier to manage and analyze your data.


With these features, MPENN streamlines the workflow for users who need to process and analyze images at scale, particularly those working with neural networks and AI applications.

# Getting Started with MPENN

Welcome to MPENN, your comprehensive tool for massive picture editing for neural networks. Follow these steps to get up and running with MPENN, and begin transforming your videos and images into machine learning-ready datasets.

## 1. Download MPENN

First, you need to obtain the MPENN software. You can download it from its Gitea repository. Use the link below to navigate to the repository, and then download the latest release suited for your operating system.
https://gitea.example.com/mpenn/releases


*Note: Replace the URL above with the actual Gitea repository link.*

## 2. Setting Up Your Environment

After downloading MPENN, it's recommended to create a virtual environment (venv) for running the software. This ensures that your Python environment remains clean and organized. Open your terminal or command prompt and navigate to the MPENN directory. Then, run the following commands:

```bash
# Create a virtual environment named 'mpenn-env'
python -m venv mpenn-env

# Activate the virtual environment
# On Windows
mpenn-env\Scripts\activate
# On Unix or MacOS
source mpenn-env/bin/activate

# Install MPENN dependencies
pip install -r requirements.txt
```

## Running MPENN

With your environment set up, you're ready to launch MPENN. Run the `main.py` File to get started

### 1. Converting Video to Picture Sequence
If you're starting with a video, MPENN makes it easy to convert it into a sequence of images. Use the video-to-picture feature to specify your video file and the output directory for the images.

### 2. Processing Image Sequences
Whether you've generated your images from a video or already have a sequence of images, you can start editing them with MPENN. You can:
    - Resize Images: Quickly adjust the resolution of your images to fit your requirements.
    - Create Bounding Boxes: Annotate your images with bounding boxes for object detection tasks.

## Documentation

Will follow soon.



## License

MPENN is made available under the [Attribution-NonCommercial-ShareAlike 4.0](.../.././LICENSE). For more details, see the LICENSE file.

## Connect with Us

Stay updated with the latest news and updates about MPENN by following us on our social media channel(s):

- [LinkedIn](https://www.linkedin.com/in/FalkoHabel/)
